# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.conf import settings
from django.utils.translation import ugettext as _
from django.contrib import admin

from jmb.jadmin.options import JumboModelAdmin

from jmb.bank.models import Bank, BankDetail


class BankInline(admin.StackedInline):
    model = Bank
    extra = 0
    fieldsets = (
        (_('general information'), {'fields': (
            'status', ('int_code', 'cin',), ('abi', 'cab',), 'cc', 'note',
        )}),
    )
    exclude = ['date_create', 'date_last_modify', 'creator', 'last_modifier']
    can_delete = False


class BankAdmin(JumboModelAdmin):
    fieldsets = (
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
            'classes': ('collapse',)
        }),
        (_('general information'), {'fields': (
            'status', 'organization', ('abi', 'cab',),
            ('int_code', 'cin', 'cc',),
            'get_detail_bank',
        )}),
    )
    list_display = (
        'get_status_icon', 'organization',
        'abi', 'cab', 'int_code', 'cin', 'cc',
        'get_edit_icon', 'get_delete_icon'
    )
    readonly_fields = ('get_detail_bank',)


class BankDetailAdmin(JumboModelAdmin):
    fieldsets = (
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
            'classes': ('collapse',)
        }),
        (_('general information'), {'fields': (
            'status', ('abi', 'cab',),
            ('name', 'agency',),
            'address', 'zip_code', 'locality', 'province', 'country'
        )})
    )
    list_display = (
        'get_status_icon', 'abi', 'cab', 'name', 'agency', 'address',
        'zip_code', 'locality', 'province', 'country', 'get_edit_icon', 'get_delete_icon'
    )
    search_fields = ('abi', 'cab', 'name',)

admin.site.register(BankDetail, BankDetailAdmin)
admin.site.register(Bank, BankAdmin)
